plot.PVE <- function(x,xlab="Number of Features",ylab="PVE",...) {

  plot(x=x$J,y=x$PVEs,xlab=xlab,ylab=ylab,...)

}
